# Import unittest
import unittest

# Import core module main file for testing
from .pypiproject_core import *

# Test case Class
class TestCoreModule(unittest.TestCase):
    
    currentResult = None # holds last result object passed to run method

    def setUp(self):
        pass

    # teardown for manage test case results
    def tearDown(self):
        ok = self.currentResult.wasSuccessful()
        errors = self.currentResult.errors
        failures = self.currentResult.failures
        print ('All tests passed so far!' if ok else \
                ' %d errors and %d failures so far' % \
                (len(errors), len(failures)))

    def run(self, result=None):
        self.currentResult = result # remember result for use in tearDown
        unittest.TestCase.run(self, result) # call superclass run method

    # Test Case 01 - Write out text in string format with default value
    def test_input(self):
        self.assertEqual(getText("test text"), "test text")

    # Test Case 02 - Write out text in string and json format
    def test_output(self):
        self.assertEqual(getText("test text", "string"), "test text")
        self.assertEqual(getText("test text", "json"), {"text": "test text"})

# Test runner function
def runUnittests():
    suite = unittest.TestSuite()
    # Check test cases in TestCoreModule class
    for method in dir(TestCoreModule):
        # Add test collection tests which start with "test"
        if method.startswith("test"):
            suite.addTest(TestCoreModule(method))
    # Return with execution and result of testcases
    return unittest.TextTestRunner(verbosity=3).run(suite)

# Run test if you use from __main__
#if __name__ == 'pypiproject.core.pypiproject_core_unittest':
    #unittest.main()
    



"""pypr - PyPi Project by the1bit
Usage:
  pypr --version
  pypr core --input TEXT
  pypr core -i TEXT -o string
  pypr core -i TEXT --output json
Arguments:
Options:
  -h --help            show this help message and exit
  -v --version         show version and exit
  --verbose            print status messages
  -i --input           set input and exit
  -o --output          output format default is string. Possible values: string, json
"""



from docopt import docopt
from pypiproject.version import __version__
__author__ = "the1bit"


arguments = docopt(__doc__, version=__version__)


if __name__ == '__main__':
  # Core module  
  if docopt(__doc__)["core"]:
      from .core.pypiproject_core import *

      # Input text
      if docopt(__doc__)["--input"]:
        # Get your text
        yourText = docopt(__doc__)["TEXT"]
        # Check outputs - if exists and json
        if docopt(__doc__)["--output"] and docopt(__doc__)["json"]:
          print([getText(yourText, 'json')])
        else:
          # default output
          print(getText(yourText))



# Help for you
#print(arguments)








"""Setuptools for pypi-project.
	Empty example PYPI package by The1bit
"""

# Always prefer setuptools over distutils
from setuptools import setup, find_packages
# To use a consistent encoding
from codecs import open
from os import path

import sys


here = path.abspath(path.dirname(__file__))



# Get the long description from the README file
with open("docs/readme.rst", "r") as fh:
    README = fh.read()

## Version of the current package
from pypiproject.version import __version__

sys.stdout.write("pypi-project: " + __version__ + '\n')


# Arguments marked as "Required" below must be included for upload to PyPI.
# Fields marked as "Optional" may be commented out.

setup(name='pypi-project',
	scripts=[
        'pypr',
        'pypr.completion.sh',
        'pypr.bat',
    ],
	python_requires='>=2.6, <3',
    version=__version__,
	description='pypi-project - Empty example PYPI package by The1bit',
	long_description=README,
	long_description_content_type="text/markdown",
	url='https://github.com/the1bit/pypi-project',
	author='the1bit',
	author_email='youremail@mustbe.valid',
	keywords='python the1bithu',
	classifiers=[  # Optional
		# How mature is this project? Common values are
		#   3 - Alpha
		#   4 - Beta
		#   5 - Production/Stable
		'Development Status :: 3 - Alpha',
		'Operating System :: Microsoft :: Windows',
		'Operating System :: POSIX :: Linux',
		# Indicate who your project is intended for
		'Intended Audience :: Developers',
		'Topic :: Software Development :: Build Tools',

		# Pick your license as you wish
		'License :: OSI Approved :: MIT License',

		# Specify the Python versions you support here. In particular, ensure
		# that you indicate whether you support Python 2, Python 3 or both.
		'Programming Language :: Python',
		'Programming Language :: Python :: 2',
		'Programming Language :: Python :: 2.7'
	],
	  packages=[
			'pypiproject',
			'pypiproject.core'
			],
		install_requires=[
			'docopt'
		],
	  license='MIT',
	  zip_safe=True)